==> mx-packageinstaller-pkglist_19.05.03.tar.xz: mx-packageinstaller-pkglist/faba-colors-icon-theme.pm <==
<?xml version="1.0"?>
<app>

<category>
Icons
</category>

<name>
Faba Icon Colors
</name>

<description>
   <am>a Faba icon theme with many colour choices</am>
   <ar>a Faba icon theme with many colour choices</ar>
   <bg>a Faba icon theme with many colour choices</bg>
   <ca>un tema d'icones Faba amb moltes opcions de color</ca>
   <cs>a Faba icon theme with many colour choices</cs>
   <da>et Faba-ikontema med mange farvevalg</da>
   <de>Ein Faba-Icon-Thema mit vielen Farbvarianten</de>
   <el>ένα θέμα εικονίδιο Faba με πολλές επιλογές χρωμάτων</el>
   <en>a Faba icon theme with many colour choices</en>
   <es>Tema de íconos Faba con colores a elección</es>
   <et>a Faba icon theme with many colour choices</et>
   <eu>a Faba icon theme with many colour choices</eu>
   <fa>a Faba icon theme with many colour choices</fa>
   <fi>a Faba icon theme with many colour choices</fi>
   <fr>Jeu d'icônes Faba aux multiples choix de couleurs</fr>
   <he_IL>a Faba icon theme with many colour choices</he_IL>
   <hi>a Faba icon theme with many colour choices</hi>
   <hr>a Faba icon theme with many colour choices</hr>
   <hu>a Faba icon theme with many colour choices</hu>
   <id>a Faba icon theme with many colour choices</id>
   <is>a Faba icon theme with many colour choices</is>
   <it>Tema di icone Faba con molte scelte di colore</it>
   <ja_JP>a Faba icon theme with many colour choices</ja_JP>
   <ja>a Faba icon theme with many colour choices</ja>
   <kk>a Faba icon theme with many colour choices</kk>
   <ko>a Faba icon theme with many colour choices</ko>
   <lt>a Faba icon theme with many colour choices</lt>
   <mk>a Faba icon theme with many colour choices</mk>
   <nb>a Faba icon theme with many colour choices</nb>
   <nl>een Faba icoon thema met veel kleurkeuzes</nl>
   <pl>motyw ikon Faba z dużym wyborem kolorów</pl>
   <pt_BR>a Faba icon theme with many colour choices</pt_BR>
   <pt>Tema de ícones Faba com muitas opções de cores</pt>
   <ro>a Faba icon theme with many colour choices</ro>
   <ru>Тема иконок Faba с множеством цветовых вариантов</ru>
   <sk>a Faba icon theme with many colour choices</sk>
   <sl>a Faba icon theme with many colour choices</sl>
   <sq>a Faba icon theme with many colour choices</sq>
   <sr>a Faba icon theme with many colour choices</sr>
   <sv>ett Faba ikontema med många färgval</sv>
   <tr>a Faba icon theme with many colour choices</tr>
   <uk>тема піктограм Faba з багатим набором кольорів</uk>
   <zh_CN>a Faba icon theme with many colour choices</zh_CN>
   <zh_TW>a Faba icon theme with many colour choices</zh_TW>
</description>

<installable>
all
</installable>

<screenshot></screenshot>

<preinstall>

</preinstall>

<install_package_names>
faba-colors-icon-theme
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
faba-colors-icon-theme
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.02.tar.xz: mx-packageinstaller-pkglist/faba-colors-icon-theme.pm <==
<?xml version="1.0"?>
<app>

<category>
Icons
</category>

<name>
Faba Icon Colors
</name>

<description>
   <am>a Faba icon theme with many colour choices</am>
   <ar>a Faba icon theme with many colour choices</ar>
   <bg>a Faba icon theme with many colour choices</bg>
   <ca>un tema d'icones Faba amb moltes opcions de color</ca>
   <cs>a Faba icon theme with many colour choices</cs>
   <da>et Faba-ikontema med mange farvevalg</da>
   <de>Ein Faba-Icon-Thema mit vielen Farbvarianten</de>
   <el>ένα θέμα εικονίδιο Faba με πολλές επιλογές χρωμάτων</el>
   <en>a Faba icon theme with many colour choices</en>
   <es>Tema de íconos Faba con colores a elección</es>
   <et>a Faba icon theme with many colour choices</et>
   <eu>a Faba icon theme with many colour choices</eu>
   <fa>a Faba icon theme with many colour choices</fa>
   <fi>a Faba icon theme with many colour choices</fi>
   <fr>Jeu d'icônes Faba aux multiples choix de couleurs</fr>
   <he_IL>a Faba icon theme with many colour choices</he_IL>
   <hi>a Faba icon theme with many colour choices</hi>
   <hr>a Faba icon theme with many colour choices</hr>
   <hu>a Faba icon theme with many colour choices</hu>
   <id>a Faba icon theme with many colour choices</id>
   <is>a Faba icon theme with many colour choices</is>
   <it>Tema di icone Faba con molte scelte di colore</it>
   <ja_JP>a Faba icon theme with many colour choices</ja_JP>
   <ja>a Faba icon theme with many colour choices</ja>
   <kk>a Faba icon theme with many colour choices</kk>
   <ko>a Faba icon theme with many colour choices</ko>
   <lt>a Faba icon theme with many colour choices</lt>
   <mk>a Faba icon theme with many colour choices</mk>
   <nb>a Faba icon theme with many colour choices</nb>
   <nl>een Faba icoon thema met veel kleurkeuzes</nl>
   <pl>motyw ikon Faba z dużym wyborem kolorów</pl>
   <pt_BR>Tema de ícones Faba com muitas opções de cores</pt_BR>
   <pt>Tema de ícones Faba com muitas opções de cores</pt>
   <ro>a Faba icon theme with many colour choices</ro>
   <ru>Тема иконок Faba с множеством цветовых вариантов</ru>
   <sk>a Faba icon theme with many colour choices</sk>
   <sl>Faba tema za ikone, z mnogimi izbori barv</sl>
   <sq>a Faba icon theme with many colour choices</sq>
   <sr>a Faba icon theme with many colour choices</sr>
   <sv>ett Faba ikontema med många färgval</sv>
   <tr>a Faba icon theme with many colour choices</tr>
   <uk>тема піктограм Faba з багатим набором кольорів</uk>
   <zh_CN>a Faba icon theme with many colour choices</zh_CN>
   <zh_TW>a Faba icon theme with many colour choices</zh_TW>
</description>

<installable>
all
</installable>

<screenshot></screenshot>

<preinstall>

</preinstall>

<install_package_names>
faba-colors-icon-theme
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
faba-colors-icon-theme
</uninstall_package_names>
</app>
